const path = require("path");
const vueConfig = require("./vue-loader.config");

module.exports = {
  devtool: "#source-map",
  entry: {
    app: "./src/entry-client.js",
    vendor: [
      "es6-promise/auto",
      "firebase/app",
      "firebase/database",
      "vue",
      "vue-router",
      "vuex",
      "vuex-router-sync"
    ]
  },
  output: {
    path: path.resolve(__dirname, "../dist"),
    publicPath: "/dist/",
    filename: "[name].[chunkhash].js"
  },
  resolve: {
    alias: {
      public: path.resolve(__dirname, "../public")
    }
  },
  module: {
    noParse: /es6-promise\.js$/, // avoid webpack shimming process
    rules: [
      {
        test: /\.vue$/,
        loader: "vue-loader",
        options: vueConfig
      },
      {
        test: /\.js$/,
        loader: "buble-loader",
        exclude: /node_modules/,
        options: {
          objectAssign: "Object.assign"
        }
      },
      {
        test: /\.(css|less)$/,
        use: ["vue-style-loader", "css-loader", "less-loader"]
      },
      {
        test: /\.(png|jpg|gif|svg)$/,
        loader: "url-loader",
        options: {
          limit: 10000,
          name: "[name].[ext]?[hash]"
        }
      },
      {
        test: /\.(woff2?|eot|ttf|otf)(\?.*)?$/,
        loader: "url-loader",
        query: {
          limit: 10000,
          name: "fonts/[name].[hash:7].[ext]"
        }
      }
    ]
  },
  performance: {
    hints: process.env.NODE_ENV === "production" ? "warning" : false
  }
};
